@@ -1,4 +1,5 @@
-createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = TRUE, show.all, show.p.trend, show.p.mul = FALSE, show.n, show.ratio = FALSE, show.descr = TRUE, hide.no = NA, digits.ratio = NA, show.p.ratio = show.ratio, digits.p = 3, sd.type = 1, q.type = c(1,1), extra.labels = NA)
+createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = TRUE, show.all, show.p.trend, show.p.mul = FALSE, show.n, show.ratio = FALSE, show.descr = TRUE, 
+                        show.ci = FALSE, hide.no = NA, digits.ratio = NA, show.p.ratio = show.ratio, digits.p = 3, sd.type = 1, q.type = c(1,1), extra.labels = NA)
 {
   
   os<-sessionInfo()$platform
@@ -9,30 +10,6 @@ createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = T
 
   spchar<-if (length(grep("linux",os))==0 || length(grep("UTF-8",locale))>0) TRUE else FALSE
 
-  # if (!is.na(extra.labels[1])){ 
-  #   method <- sapply(x, function(x.i) paste(attr(x.i, "method"),collapse="-"))
-  #   method <- ifelse(method=="continuous-normal", 1, ifelse(method=="continuous-non-normal", 2, 3))
-  #   Q1 <- attr(x,"Q1")
-  #   Q3 <- attr(x,"Q3")
-  #   if (extra.labels[1]=="")
-  #     extra.labels[1] <- if (sd.type==1) "Mean (SD)" else "Mean\u00B1SD"
-  #   if (extra.labels[2]=="")
-  #     extra.labels[2] <- paste0("Median ",ifelse(q.type[1]==1,"[","("),Q1*100,"th",ifelse(q.type[2]==1,";",ifelse(q.type[2]==2,",","-")),Q3*100,"th",ifelse(q.type[1]==1,"]",")"))
-  #   if (extra.labels[3]==""){
-  #     if (is.na(type) || type==2)
-  #       extra.labels[3] <- "N (%)"
-  #     else {
-  #       if (type==1) extra.labels[3] <- "%"
-  #       if (type==3) extra.labels[3] <- "N"
-  #     }
-  #   }
-  #   names(x) <- paste(names(x), 
-  #                     ifelse(method==1, extra.labels[1],
-  #                     ifelse(method==2, extra.labels[2],
-  #                     ifelse(method==3, extra.labels[3], ""))), sep=", ")
-  # }
-  
-  
   if (any(!is.na(extra.labels))){ 
     method <- sapply(x, function(x.i) paste(attr(x.i, "method"),collapse="-"))
     method <- ifelse(method=="continuous-normal", 1, ifelse(method=="continuous-non-normal", 2, 3))
@@ -128,7 +105,7 @@ createTable <- function(x, hide = NA, digits = NA, type = NA, show.p.overall = T
   nr<-NULL
   k<-1
   for (i in 1:length(x)){
-    t.i<-t(table.i(x[[i]],hide.i=hide[[i]],digits=digits[i],digits.ratio=digits.ratio[i],type=type,varname=varnames[i],hide.no,digits.p=digits.p,sd.type=sd.type,q.type=q.type,spchar=spchar))
+    t.i<-t(table.i(x[[i]],hide.i=hide[[i]],digits=digits[i],digits.ratio=digits.ratio[i],type=type,varname=varnames[i],hide.no,digits.p=digits.p,sd.type=sd.type,q.type=q.type,spchar=spchar,show.ci=show.ci))
     nr<-c(nr,nrow(t.i))
     ans$descr<-rbind(ans$descr,t.i)
     s.i<-attr(x[[i]],"selec")
